akhdefo_functions.DynamicChangeDetection — akhdefo 2023 documentation

# akhdefo_functions.DynamicChangeDetection

akhdefo_functions.DynamicChangeDetection(Path_working_Directory='', Path_UDM2_folder='', Path_to_DEMFile='', Coh_Thresh=0.75, vel_thresh=0.063, udm_mask_option=False, cmap='jet', Median_Filter=False, Set_fig_MinMax=False, show_figure=False, plot_option='origional')

  This program calculates optical flow velocity from triplets of daily optical satellite images.

  Path_working_Directory=r””

  Path_UDM2_folder=r””

  Path_to_DEMFile=r””

  Coh_Thresh=0.75

  vel_thresh=0.063

  udm_mask_option=False

  cmap=’jet’

  Median_Filter=False

  Set_fig_MinMax=False

  show_figure=False

  plot_option=”origional”

  Outputs: Raster velocity in X direction(EW) Raster Velocity in Y direction(NS) Initial Timesereis Figures (those figures are only intermediate products needs calibration)

  Note: Final Timeseris products will be a shapefile format using Time_Series function after stackprep step.